pitchtools.IntervalSegment
==========================

.. abjad-lineage:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment

.. autoclass:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.count
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.from_selection
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.has_duplicates
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.index
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.item_class
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.items
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.rotate
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.slope
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.spread
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__add__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__contains__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__eq__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__format__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__getitem__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__getslice__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__hash__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__iter__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__len__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__mul__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__ne__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__radd__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__repr__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__rmul__
      ~abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__str__

Bases
-----

- :py:class:`pitchtools.Segment <abjad.tools.pitchtools.Segment.Segment>`

- :py:class:`datastructuretools.TypedTuple <abjad.tools.datastructuretools.TypedTuple.TypedTuple>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.has_duplicates
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.item_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.items
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.slope
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.spread
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.count
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.index
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.rotate
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__getslice__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__mul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__radd__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__rmul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalSegment.IntervalSegment.__str__
   :noindex:
